@@ -83,15 +83,14 @@ class SalesforceBulk(object):
 
     def __init__(self, sessionId=None, host=None, username=None, password=None,
                  API_version=DEFAULT_API_VERSION, sandbox=False,
-                 security_token=None, organizationId=None, client_id=None, domain=None):
+                 security_token=None, organizationId=None, client_id=None):
         if not sessionId and not username:
             raise RuntimeError(
                 "Must supply either sessionId/instance_url or username/password")
         if not sessionId:
             sessionId, host = SalesforceBulk.login_to_salesforce(
                 username, password, sandbox=sandbox, security_token=security_token,
-                organizationId=organizationId, API_version=API_version, client_id=client_id,
-                domain=domain)
+                organizationId=organizationId, API_version=API_version, client_id=client_id)
 
         if host[0:4] == 'http':
             self.endpoint = host
@@ -108,10 +107,7 @@ class SalesforceBulk(object):
 
     @staticmethod
     def login_to_salesforce(username, password, sandbox=False, security_token=None,
-                            organizationId=None, client_id=None, API_version=DEFAULT_API_VERSION,
-                            # domain is passed directly to SalesforceLogin and should be 'test' or
-                            # 'login' or 'something.my'
-                            domain=None):
+                            organizationId=None, client_id=None, API_version=DEFAULT_API_VERSION):
         if client_id:
             client_id = "{prefix}/{app_name}".format(
                 prefix=DEFAULT_CLIENT_ID_PREFIX,
@@ -119,9 +115,6 @@ class SalesforceBulk(object):
         else:
             client_id = DEFAULT_CLIENT_ID_PREFIX
 
-        if domain is None and sandbox:
-            domain = 'test'
-
         if all(arg is not None for arg in (
                 username, password, security_token)):
 
@@ -130,7 +123,6 @@ class SalesforceBulk(object):
                 username=username,
                 password=password,
                 security_token=security_token,
-                domain=domain,
                 sf_version=API_version,
                 client_id=client_id)
 
@@ -142,7 +134,6 @@ class SalesforceBulk(object):
                 username=username,
                 password=password,
                 organizationId=organizationId,
-                domain=domain,
                 sf_version=API_version,
                 client_id=client_id)
 
@@ -181,11 +172,11 @@ class SalesforceBulk(object):
         return self.create_job(object_name, "delete", **kwargs)
 
     def create_job(self, object_name=None, operation=None, contentType='CSV',
-                   concurrency=None, external_id_name=None, pk_chunking=False):
+                   concurrency=None, external_id_name=None, pk_chunking=False,
+                   extra_headers={}):
         assert(object_name is not None)
         assert(operation is not None)
 
-        extra_headers = {}
         if pk_chunking:
             if pk_chunking is True:
                 pk_chunking = u'true'
@@ -306,10 +297,10 @@ class SalesforceBulk(object):
     def query(self, job_id, soql, contentType='CSV'):
         if job_id is None:
             job_id = self.create_job(
-                re.search(re.compile(r"from (\w+)", re.I), soql).group(1),
+                re.search(re.compile("from (\w+)", re.I), soql).group(1),
                 "query", contentType=contentType)
 
-        job_content_type = self.job_content_types.get(job_id, contentType)
+        job_content_type = self.job_content_types[job_id]
         http_content_type = job_to_http_content_type[job_content_type]
 
         headers = self.headers(content_type=http_content_type)
